# AnimeStreamer-CLI
CLI for searching through https://nyaa.si/ and streaming torrents via WebTorrent.

## Dependencies
webtorrent-cli: https://github.com/webtorrent/webtorrent-cli: => `npm install webtorrent-cli -g`


## Install and run
1. `pip install animestreamer`
2. `animestreamer`

## Usage
Type `help` or `help [command]` after starting the application.